pub enum SessionTeardownKind {
Deleted,
NotDeleted,
}Expand description
Representation of whether we managed to successfully send a DeleteSession message and read the response during session teardown.
Variants
Deleted
A DeleteSession message has been sent and the response handled.
NotDeleted
No DeleteSession message has been sent, or the response was not received.